The names of the countries with national and subnational administration level data stored
Source:R/country_names.R
country_names.RdThe names of the countries with national and subnational administration level data stored
Format
A data frame with 30 rows and 3 columns:
- Country names
Country name
- National level data available
Indicator for whether data at the national administration level is available in the package
- Subnational level data available
Indicator for whether data at the subnational administration level is available in the package