An array of variance-covariance matrices transformed onto the logit-scale via the delta method. Each matrix corresponds to the DHS survey logit-transformed observations for the proportion of modern contraceptives supplied by the public and private sectors at the national level
Source:R/national_FPsource_VARCOV_bivarlogitnormal.R
national_FPsource_VARCOV_bivarlogitnormal.RdAn array of variance-covariance matrices transformed onto the logit-scale via the delta method. Each matrix corresponds to the DHS survey logit-transformed observations for the proportion of modern contraceptives supplied by the public and private sectors at the national level