The median estimates of the national-level sub-continental, sector-, method-specific intercepts in the multi-country national model. This array is used to inform the Normal prior of the country-level intercept in the single-country national model.
Source:R/national_theta_rms_hat_bivarlogitnormal.R
national_theta_rms_hat_bivarlogitnorm.RdThe median estimates of the national-level sub-continental, sector-, method-specific intercepts in the multi-country national model. This array is used to inform the Normal prior of the country-level intercept in the single-country national model.