The order of observations to join the variance-covariance array data and the DHS survey observations for the proportion of modern contraceptives supplied by the public and private sectors at the national level
Source:R/national_varcov_order_bivarlogitnormal.R
national_varcov_order_bivarlogitnormal.RdThe order of observations to join the variance-covariance array data and the DHS survey observations for the proportion of modern contraceptives supplied by the public and private sectors at the national level