Learn R Programming

mcmsupply (version 1.1.1)

subnational_alpha_cms_hat: The median estimates of the subnational-level country, sector-, method-specific intercepts in the multi-country subnational model. This array is used to inform the Normal prior of the subnational-level intercept in the single-country subnational model.

Description

The median estimates of the subnational-level country, sector-, method-specific intercepts in the multi-country subnational model. This array is used to inform the Normal prior of the subnational-level intercept in the single-country subnational model.

Usage

subnational_alpha_cms_hat

Arguments

Format

A array of 23 matrices with 2 rows and 5 columns