Learn R Programming

mcmsupply (version 1.1.1)

subnational_estimated_correlations: The estimated subnational-level correlations between the rates of change in methods

Description

The estimated subnational-level correlations between the rates of change in methods

Usage

subnational_estimated_correlations

Arguments

Format

A array of 2 matrices with 5 rows and 5 columns:

row

Contraceptive method the correlation estimate refers to

column

Contraceptive method the correlation estimate refers to

public_cor

The estimated correlation between the rates of change in methods supplied by the public sector

private_cor

The estimated correlation between the rates of change in methods supplied by the private sector